@@ -3,7 +3,7 @@
 # Author: Mike McKerns (mmckerns @caltech and @uqfoundation)
 # Author: Leonardo Gama (@leogama)
 # Copyright (c) 2008-2015 California Institute of Technology.
-# Copyright (c) 2016-2023 The Uncertainty Quantification Foundation.
+# Copyright (c) 2016-2024 The Uncertainty Quantification Foundation.
 # License: 3-clause BSD.  The full license text is available at:
 #  - https://github.com/uqfoundation/dill/blob/master/LICENSE
 """
@@ -19,22 +19,21 @@ import re
 import os
 import sys
 import warnings
+import pathlib
+import tempfile
+
+TEMPDIR = pathlib.PurePath(tempfile.gettempdir())
+
+# Type hints.
+from typing import Optional, Union
 
 from dill import _dill, Pickler, Unpickler
 from ._dill import (
     BuiltinMethodType, FunctionType, MethodType, ModuleType, TypeType,
     _import_module, _is_builtin_module, _is_imported_module, _main_module,
-    _reverse_typemap, __builtin__,
+    _reverse_typemap, __builtin__, UnpicklingError,
 )
 
-# Type hints.
-from typing import Optional, Union
-
-import pathlib
-import tempfile
-
-TEMPDIR = pathlib.PurePath(tempfile.gettempdir())
-
 def _module_map():
     """get map of imported modules"""
     from collections import defaultdict
